@@ -11,7 +11,7 @@ def cat(
     remotepath: str,
     max_chunk_size: int = DEFAULT_MAX_CHUNK_SIZE,
     encoding: Optional[str] = None,
-    encrypt_key=Optional[str],
+    encrypt_key: bytes = b"",
 ):
     rangeRequestIO = api.file_stream(remotepath, encrypt_key=encrypt_key)
     cn = rangeRequestIO.read()
