@@ -1,4 +1,3 @@
-from typing import Any
 from os import PathLike
 from pathlib import Path
 
@@ -7,7 +6,7 @@ from baidupcs_py.common.path import exists
 
 
 def decrypt_file(
-    from_encrypted: PathLike, to_decrypted: PathLike, encrypt_key: Any = None
+    from_encrypted: PathLike, to_decrypted: PathLike, encrypt_key: bytes = b""
 ):
     assert exists(from_encrypted)
 
