@@ -39,8 +39,8 @@ def sync(
     api: BaiduPCSApi,
     localdir: str,
     remotedir: str,
-    encrypt_key: Any = None,
-    salt: Any = None,
+    encrypt_key: bytes = b"",
+    salt: bytes = b"",
     encrypt_type: EncryptType = EncryptType.No,
     max_workers: int = CPU_NUM,
     slice_size: int = DEFAULT_SLICE_SIZE,
